==> syncope-3.0.11-source-release.zip: syncope-3.0.11/common/am/lib/src/main/java/org/apache/syncope/common/lib/wa/WebAuthnDeviceCredential.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.wa;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.syncope.common.lib.BaseBean;

public class WebAuthnDeviceCredential implements BaseBean {

    private static final long serialVersionUID = 1185073386484048953L;

    public static class Builder {

        private final WebAuthnDeviceCredential instance = new WebAuthnDeviceCredential();

        public WebAuthnDeviceCredential.Builder json(final String json) {
            instance.setJson(json);
            return this;
        }

        public WebAuthnDeviceCredential.Builder identifier(final String identifier) {
            instance.setIdentifier(identifier);
            return this;
        }

        public WebAuthnDeviceCredential build() {
            return instance;
        }
    }

    private String json;

    private String identifier;

    public String getIdentifier() {
        return identifier;
    }

    public void setIdentifier(final String identifier) {
        this.identifier = identifier;
    }

    public String getJson() {
        return json;
    }

    public void setJson(final String json) {
        this.json = json;
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder()
                .append(json)
                .append(identifier)
                .toHashCode();
    }

    @Override
    public boolean equals(final Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        WebAuthnDeviceCredential other = (WebAuthnDeviceCredential) obj;
        return new EqualsBuilder()
                .append(this.json, other.json)
                .append(this.identifier, other.identifier)
                .isEquals();
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("records", json)
                .append("identifier", identifier)
                .toString();
    }
}

==> syncope-4.0.2-source-release.zip: syncope-4.0.2/common/am/lib/src/main/java/org/apache/syncope/common/lib/wa/WebAuthnDeviceCredential.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.wa;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.syncope.common.lib.BaseBean;

public class WebAuthnDeviceCredential implements BaseBean {

    private static final long serialVersionUID = 1185073386484048953L;

    public static class Builder {

        private final WebAuthnDeviceCredential instance = new WebAuthnDeviceCredential();

        public WebAuthnDeviceCredential.Builder json(final String json) {
            instance.setJson(json);
            return this;
        }

        public WebAuthnDeviceCredential.Builder identifier(final String identifier) {
            instance.setIdentifier(identifier);
            return this;
        }

        public WebAuthnDeviceCredential build() {
            return instance;
        }
    }

    private String json;

    private String identifier;

    public String getIdentifier() {
        return identifier;
    }

    public void setIdentifier(final String identifier) {
        this.identifier = identifier;
    }

    public String getJson() {
        return json;
    }

    public void setJson(final String json) {
        this.json = json;
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder()
                .append(json)
                .append(identifier)
                .build();
    }

    @Override
    public boolean equals(final Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        WebAuthnDeviceCredential other = (WebAuthnDeviceCredential) obj;
        return new EqualsBuilder()
                .append(json, other.json)
                .append(identifier, other.identifier)
                .build();
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("records", json)
                .append("identifier", identifier)
                .build();
    }
}
